# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/http_uri.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/http_uri.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\014HttpUriProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/core/v3/http_uri.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x01\n\x07HttpUri\x12\x14\n\x03uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\x07\x63luster\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x36\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01\x32\x00: \x9a\xc5\x88\x1e\x1b\n\x19\x65nvoy.api.v2.core.HttpUriB\x19\n\x12http_upstream_type\x12\x03\xf8\x42\x01\x42<\n\"io.envoyproxy.envoy.config.core.v3B\x0cHttpUriProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HTTPURI = _descriptor.Descriptor(
  name='HttpUri',
  full_name='envoy.config.core.v3.HttpUri',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.config.core.v3.HttpUri.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.core.v3.HttpUri.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.config.core.v3.HttpUri.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\0012\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\033\n\031envoy.api.v2.core.HttpUri',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='http_upstream_type', full_name='envoy.config.core.v3.HttpUri.http_upstream_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=185,
  serialized_end=361,
)

_HTTPURI.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPURI.oneofs_by_name['http_upstream_type'].fields.append(
  _HTTPURI.fields_by_name['cluster'])
_HTTPURI.fields_by_name['cluster'].containing_oneof = _HTTPURI.oneofs_by_name['http_upstream_type']
DESCRIPTOR.message_types_by_name['HttpUri'] = _HTTPURI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpUri = _reflection.GeneratedProtocolMessageType('HttpUri', (_message.Message,), {
  'DESCRIPTOR' : _HTTPURI,
  '__module__' : 'envoy.config.core.v3.http_uri_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HttpUri)
  })
_sym_db.RegisterMessage(HttpUri)


DESCRIPTOR._options = None
_HTTPURI.oneofs_by_name['http_upstream_type']._options = None
_HTTPURI.fields_by_name['uri']._options = None
_HTTPURI.fields_by_name['cluster']._options = None
_HTTPURI.fields_by_name['timeout']._options = None
_HTTPURI._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/bootstrap/v4alpha/bootstrap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v4alpha import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v4alpha_dot_cluster__pb2
from envoy.config.core.v4alpha import address_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2
from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.core.v4alpha import event_service_config_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_event__service__config__pb2
from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from envoy.config.core.v4alpha import socket_option_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_socket__option__pb2
from envoy.config.listener.v4alpha import listener_pb2 as envoy_dot_config_dot_listener_dot_v4alpha_dot_listener__pb2
from envoy.config.metrics.v4alpha import stats_pb2 as envoy_dot_config_dot_metrics_dot_v4alpha_dot_stats__pb2
from envoy.config.overload.v3 import overload_pb2 as envoy_dot_config_dot_overload_dot_v3_dot_overload__pb2
from envoy.extensions.transport_sockets.tls.v4alpha import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import security_pb2 as udpa_dot_annotations_dot_security__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/bootstrap/v4alpha/bootstrap.proto',
  package='envoy.config.bootstrap.v4alpha',
  syntax='proto3',
  serialized_options=b'\n,io.envoyproxy.envoy.config.bootstrap.v4alphaB\016BootstrapProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/config/bootstrap/v4alpha/bootstrap.proto\x12\x1e\x65nvoy.config.bootstrap.v4alpha\x1a*envoy/config/cluster/v4alpha/cluster.proto\x1a\'envoy/config/core/v4alpha/address.proto\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a\x34\x65nvoy/config/core/v4alpha/event_service_config.proto\x1a)envoy/config/core/v4alpha/extension.proto\x1a-envoy/config/core/v4alpha/socket_option.proto\x1a,envoy/config/listener/v4alpha/listener.proto\x1a(envoy/config/metrics/v4alpha/stats.proto\x1a\'envoy/config/overload/v3/overload.proto\x1a;envoy/extensions/transport_sockets/tls/v4alpha/secret.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fudpa/annotations/security.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbc\x12\n\tBootstrap\x12-\n\x04node\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v4alpha.Node\x12\x1b\n\x13node_context_params\x18\x1a \x03(\t\x12S\n\x10static_resources\x18\x02 \x01(\x0b\x32\x39.envoy.config.bootstrap.v4alpha.Bootstrap.StaticResources\x12U\n\x11\x64ynamic_resources\x18\x03 \x01(\x0b\x32:.envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources\x12G\n\x0f\x63luster_manager\x18\x04 \x01(\x0b\x32..envoy.config.bootstrap.v4alpha.ClusterManager\x12>\n\nhds_config\x18\x0e \x01(\x0b\x32*.envoy.config.core.v4alpha.ApiConfigSource\x12\x12\n\nflags_path\x18\x05 \x01(\t\x12<\n\x0bstats_sinks\x18\x06 \x03(\x0b\x32\'.envoy.config.metrics.v4alpha.StatsSink\x12?\n\x0cstats_config\x18\r \x01(\x0b\x32).envoy.config.metrics.v4alpha.StatsConfig\x12L\n\x14stats_flush_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\x11\xfa\x42\x0e\xaa\x01\x0b\x1a\x03\x08\xac\x02\x32\x04\x10\xc0\x84=H\x00\x12\'\n\x14stats_flush_on_admin\x18\x1d \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12<\n\twatchdogs\x18\x1b \x01(\x0b\x32).envoy.config.bootstrap.v4alpha.Watchdogs\x12G\n\x0flayered_runtime\x18\x11 \x01(\x0b\x32..envoy.config.bootstrap.v4alpha.LayeredRuntime\x12\x34\n\x05\x61\x64min\x18\x0c \x01(\x0b\x32%.envoy.config.bootstrap.v4alpha.Admin\x12S\n\x10overload_manager\x18\x0f \x01(\x0b\x32).envoy.config.overload.v3.OverloadManagerB\x0e\x8a\x93\xb7*\x02\x08\x01\x8a\x93\xb7*\x02\x10\x01\x12\x1f\n\x17\x65nable_dispatcher_stats\x18\x10 \x01(\x08\x12\x15\n\rheader_prefix\x18\x12 \x01(\t\x12\x43\n\x1dstats_server_version_override\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1f\n\x17use_tcp_for_dns_lookups\x18\x14 \x01(\x08\x12M\n\x14\x62ootstrap_extensions\x18\x15 \x03(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig\x12\x42\n\rfatal_actions\x18\x1c \x03(\x0b\x32+.envoy.config.bootstrap.v4alpha.FatalAction\x12?\n\x0e\x63onfig_sources\x18\x16 \x03(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource\x12\x46\n\x15\x64\x65\x66\x61ult_config_source\x18\x17 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource\x12 \n\x18\x64\x65\x66\x61ult_socket_interface\x18\x18 \x01(\t\x12s\n\x1e\x63\x65rtificate_provider_instances\x18\x19 \x03(\x0b\x32K.envoy.config.bootstrap.v4alpha.Bootstrap.CertificateProviderInstancesEntry\x1a\x8b\x02\n\x0fStaticResources\x12:\n\tlisteners\x18\x01 \x03(\x0b\x32\'.envoy.config.listener.v4alpha.Listener\x12\x37\n\x08\x63lusters\x18\x02 \x03(\x0b\x32%.envoy.config.cluster.v4alpha.Cluster\x12G\n\x07secrets\x18\x03 \x03(\x0b\x32\x36.envoy.extensions.transport_sockets.tls.v4alpha.Secret::\x9a\xc5\x88\x1e\x35\n3envoy.config.bootstrap.v3.Bootstrap.StaticResources\x1a\xcd\x02\n\x10\x44ynamicResources\x12;\n\nlds_config\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource\x12\x1d\n\x15lds_resources_locator\x18\x05 \x01(\t\x12;\n\ncds_config\x18\x02 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource\x12\x1d\n\x15\x63\x64s_resources_locator\x18\x06 \x01(\t\x12>\n\nads_config\x18\x03 \x01(\x0b\x32*.envoy.config.core.v4alpha.ApiConfigSource:;\x9a\xc5\x88\x1e\x36\n4envoy.config.bootstrap.v3.Bootstrap.DynamicResourcesJ\x04\x08\x04\x10\x05\x1at\n!CertificateProviderInstancesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig:\x02\x38\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.bootstrap.v3.BootstrapB\r\n\x0bstats_flushJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x08\x10\tJ\x04\x08\t\x10\nR\x07runtimeR\x08watchdogR\x07tracing\"\xd4\x01\n\x05\x41\x64min\x12\x17\n\x0f\x61\x63\x63\x65ss_log_path\x18\x01 \x01(\t\x12\x14\n\x0cprofile_path\x18\x02 \x01(\t\x12\x33\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\".envoy.config.core.v4alpha.Address\x12?\n\x0esocket_options\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v4alpha.SocketOption:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.bootstrap.v3.Admin\"\xfa\x03\n\x0e\x43lusterManager\x12\x1a\n\x12local_cluster_name\x18\x01 \x01(\t\x12Z\n\x11outlier_detection\x18\x02 \x01(\x0b\x32?.envoy.config.bootstrap.v4alpha.ClusterManager.OutlierDetection\x12\x43\n\x14upstream_bind_config\x18\x03 \x01(\x0b\x32%.envoy.config.core.v4alpha.BindConfig\x12\x45\n\x11load_stats_config\x18\x04 \x01(\x0b\x32*.envoy.config.core.v4alpha.ApiConfigSource\x1a\xb2\x01\n\x10OutlierDetection\x12\x16\n\x0e\x65vent_log_path\x18\x01 \x01(\t\x12\x44\n\revent_service\x18\x02 \x01(\x0b\x32-.envoy.config.core.v4alpha.EventServiceConfig:@\x9a\xc5\x88\x1e;\n9envoy.config.bootstrap.v3.ClusterManager.OutlierDetection:/\x9a\xc5\x88\x1e*\n(envoy.config.bootstrap.v3.ClusterManager\"\xc2\x01\n\tWatchdogs\x12\x46\n\x14main_thread_watchdog\x18\x01 \x01(\x0b\x32(.envoy.config.bootstrap.v4alpha.Watchdog\x12\x41\n\x0fworker_watchdog\x18\x02 \x01(\x0b\x32(.envoy.config.bootstrap.v4alpha.Watchdog:*\x9a\xc5\x88\x1e%\n#envoy.config.bootstrap.v3.Watchdogs\"\x84\x06\n\x08Watchdog\x12H\n\x07\x61\x63tions\x18\x07 \x03(\x0b\x32\x37.envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction\x12/\n\x0cmiss_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10megamiss_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0ckill_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x17max_kill_timeout_jitter\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x32\x00\x12\x34\n\x11multikill_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x13multikill_threshold\x18\x05 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x1a\xba\x02\n\x0eWatchdogAction\x12?\n\x06\x63onfig\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig\x12^\n\x05\x65vent\x18\x02 \x01(\x0e\x32\x45.envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction.WatchdogEventB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"M\n\rWatchdogEvent\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04KILL\x10\x01\x12\r\n\tMULTIKILL\x10\x02\x12\x0c\n\x08MEGAMISS\x10\x03\x12\x08\n\x04MISS\x10\x04:8\x9a\xc5\x88\x1e\x33\n1envoy.config.bootstrap.v3.Watchdog.WatchdogAction:)\x9a\xc5\x88\x1e$\n\"envoy.config.bootstrap.v3.Watchdog\"|\n\x0b\x46\x61talAction\x12?\n\x06\x63onfig\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig:,\x9a\xc5\x88\x1e\'\n%envoy.config.bootstrap.v3.FatalAction\"\xa5\x01\n\x07Runtime\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x02 \x01(\t\x12\x1d\n\x15override_subdirectory\x18\x03 \x01(\t\x12%\n\x04\x62\x61se\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct:(\x9a\xc5\x88\x1e#\n!envoy.config.bootstrap.v3.Runtime\"\xf7\x05\n\x0cRuntimeLayer\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12/\n\x0cstatic_layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12L\n\ndisk_layer\x18\x03 \x01(\x0b\x32\x36.envoy.config.bootstrap.v4alpha.RuntimeLayer.DiskLayerH\x00\x12N\n\x0b\x61\x64min_layer\x18\x04 \x01(\x0b\x32\x37.envoy.config.bootstrap.v4alpha.RuntimeLayer.AdminLayerH\x00\x12L\n\nrtds_layer\x18\x05 \x01(\x0b\x32\x36.envoy.config.bootstrap.v4alpha.RuntimeLayer.RtdsLayerH\x00\x1a\x90\x01\n\tDiskLayer\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x03 \x01(\t\x12\x1e\n\x16\x61ppend_service_cluster\x18\x02 \x01(\x08:7\x9a\xc5\x88\x1e\x32\n0envoy.config.bootstrap.v3.RuntimeLayer.DiskLayer\x1a\x46\n\nAdminLayer:8\x9a\xc5\x88\x1e\x33\n1envoy.config.bootstrap.v3.RuntimeLayer.AdminLayer\x1a\x90\x01\n\tRtdsLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0brtds_config\x18\x02 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSource:7\x9a\xc5\x88\x1e\x32\n0envoy.config.bootstrap.v3.RuntimeLayer.RtdsLayer:-\x9a\xc5\x88\x1e(\n&envoy.config.bootstrap.v3.RuntimeLayerB\x16\n\x0flayer_specifier\x12\x03\xf8\x42\x01\"\x7f\n\x0eLayeredRuntime\x12<\n\x06layers\x18\x01 \x03(\x0b\x32,.envoy.config.bootstrap.v4alpha.RuntimeLayer:/\x9a\xc5\x88\x1e*\n(envoy.config.bootstrap.v3.LayeredRuntimeBH\n,io.envoyproxy.envoy.config.bootstrap.v4alphaB\x0e\x42ootstrapProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_cluster_dot_v4alpha_dot_cluster__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_event__service__config__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_socket__option__pb2.DESCRIPTOR,envoy_dot_config_dot_listener_dot_v4alpha_dot_listener__pb2.DESCRIPTOR,envoy_dot_config_dot_metrics_dot_v4alpha_dot_stats__pb2.DESCRIPTOR,envoy_dot_config_dot_overload_dot_v3_dot_overload__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_security__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT = _descriptor.EnumDescriptor(
  name='WatchdogEvent',
  full_name='envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction.WatchdogEvent',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KILL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTIKILL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEGAMISS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4716,
  serialized_end=4793,
)
_sym_db.RegisterEnumDescriptor(_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT)


_BOOTSTRAP_STATICRESOURCES = _descriptor.Descriptor(
  name='StaticResources',
  full_name='envoy.config.bootstrap.v4alpha.Bootstrap.StaticResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listeners', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.StaticResources.listeners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusters', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.StaticResources.clusters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.StaticResources.secrets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.bootstrap.v3.Bootstrap.StaticResources',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2366,
  serialized_end=2633,
)

_BOOTSTRAP_DYNAMICRESOURCES = _descriptor.Descriptor(
  name='DynamicResources',
  full_name='envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lds_config', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources.lds_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lds_resources_locator', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources.lds_resources_locator', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cds_config', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources.cds_config', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cds_resources_locator', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources.cds_resources_locator', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_config', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources.ads_config', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.config.bootstrap.v3.Bootstrap.DynamicResources',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2636,
  serialized_end=2969,
)

_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY = _descriptor.Descriptor(
  name='CertificateProviderInstancesEntry',
  full_name='envoy.config.bootstrap.v4alpha.Bootstrap.CertificateProviderInstancesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.CertificateProviderInstancesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.CertificateProviderInstancesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2971,
  serialized_end=3087,
)

_BOOTSTRAP = _descriptor.Descriptor(
  name='Bootstrap',
  full_name='envoy.config.bootstrap.v4alpha.Bootstrap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_context_params', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.node_context_params', index=1,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_resources', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.static_resources', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_resources', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.dynamic_resources', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_manager', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.cluster_manager', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hds_config', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.hds_config', index=5,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags_path', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.flags_path', index=6,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_sinks', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.stats_sinks', index=7,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_config', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.stats_config', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_flush_interval', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.stats_flush_interval', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\016\252\001\013\032\003\010\254\0022\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_flush_on_admin', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.stats_flush_on_admin', index=10,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdogs', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.watchdogs', index=11,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layered_runtime', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.layered_runtime', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.admin', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overload_manager', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.overload_manager', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\010\001\212\223\267*\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_dispatcher_stats', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.enable_dispatcher_stats', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_prefix', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.header_prefix', index=16,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_server_version_override', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.stats_server_version_override', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_tcp_for_dns_lookups', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.use_tcp_for_dns_lookups', index=18,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bootstrap_extensions', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.bootstrap_extensions', index=19,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fatal_actions', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.fatal_actions', index=20,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_sources', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.config_sources', index=21,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config_source', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.default_config_source', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_socket_interface', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.default_socket_interface', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_provider_instances', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.certificate_provider_instances', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BOOTSTRAP_STATICRESOURCES, _BOOTSTRAP_DYNAMICRESOURCES, _BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.bootstrap.v3.Bootstrap',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='stats_flush', full_name='envoy.config.bootstrap.v4alpha.Bootstrap.stats_flush',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=834,
  serialized_end=3198,
)


_ADMIN = _descriptor.Descriptor(
  name='Admin',
  full_name='envoy.config.bootstrap.v4alpha.Admin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_log_path', full_name='envoy.config.bootstrap.v4alpha.Admin.access_log_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_path', full_name='envoy.config.bootstrap.v4alpha.Admin.profile_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.config.bootstrap.v4alpha.Admin.address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_options', full_name='envoy.config.bootstrap.v4alpha.Admin.socket_options', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.config.bootstrap.v3.Admin',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3201,
  serialized_end=3413,
)


_CLUSTERMANAGER_OUTLIERDETECTION = _descriptor.Descriptor(
  name='OutlierDetection',
  full_name='envoy.config.bootstrap.v4alpha.ClusterManager.OutlierDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_log_path', full_name='envoy.config.bootstrap.v4alpha.ClusterManager.OutlierDetection.event_log_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_service', full_name='envoy.config.bootstrap.v4alpha.ClusterManager.OutlierDetection.event_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.config.bootstrap.v3.ClusterManager.OutlierDetection',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3695,
  serialized_end=3873,
)

_CLUSTERMANAGER = _descriptor.Descriptor(
  name='ClusterManager',
  full_name='envoy.config.bootstrap.v4alpha.ClusterManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_cluster_name', full_name='envoy.config.bootstrap.v4alpha.ClusterManager.local_cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outlier_detection', full_name='envoy.config.bootstrap.v4alpha.ClusterManager.outlier_detection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_bind_config', full_name='envoy.config.bootstrap.v4alpha.ClusterManager.upstream_bind_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_stats_config', full_name='envoy.config.bootstrap.v4alpha.ClusterManager.load_stats_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERMANAGER_OUTLIERDETECTION, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.bootstrap.v3.ClusterManager',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3416,
  serialized_end=3922,
)


_WATCHDOGS = _descriptor.Descriptor(
  name='Watchdogs',
  full_name='envoy.config.bootstrap.v4alpha.Watchdogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='main_thread_watchdog', full_name='envoy.config.bootstrap.v4alpha.Watchdogs.main_thread_watchdog', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_watchdog', full_name='envoy.config.bootstrap.v4alpha.Watchdogs.worker_watchdog', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.bootstrap.v3.Watchdogs',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3925,
  serialized_end=4119,
)


_WATCHDOG_WATCHDOGACTION = _descriptor.Descriptor(
  name='WatchdogAction',
  full_name='envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction.event', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT,
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.bootstrap.v3.Watchdog.WatchdogAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4537,
  serialized_end=4851,
)

_WATCHDOG = _descriptor.Descriptor(
  name='Watchdog',
  full_name='envoy.config.bootstrap.v4alpha.Watchdog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='envoy.config.bootstrap.v4alpha.Watchdog.actions', index=0,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miss_timeout', full_name='envoy.config.bootstrap.v4alpha.Watchdog.miss_timeout', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='megamiss_timeout', full_name='envoy.config.bootstrap.v4alpha.Watchdog.megamiss_timeout', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kill_timeout', full_name='envoy.config.bootstrap.v4alpha.Watchdog.kill_timeout', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_kill_timeout_jitter', full_name='envoy.config.bootstrap.v4alpha.Watchdog.max_kill_timeout_jitter', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\0022\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multikill_timeout', full_name='envoy.config.bootstrap.v4alpha.Watchdog.multikill_timeout', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multikill_threshold', full_name='envoy.config.bootstrap.v4alpha.Watchdog.multikill_threshold', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WATCHDOG_WATCHDOGACTION, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.bootstrap.v3.Watchdog',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4122,
  serialized_end=4894,
)


_FATALACTION = _descriptor.Descriptor(
  name='FatalAction',
  full_name='envoy.config.bootstrap.v4alpha.FatalAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.config.bootstrap.v4alpha.FatalAction.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.config.bootstrap.v3.FatalAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4896,
  serialized_end=5020,
)


_RUNTIME = _descriptor.Descriptor(
  name='Runtime',
  full_name='envoy.config.bootstrap.v4alpha.Runtime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symlink_root', full_name='envoy.config.bootstrap.v4alpha.Runtime.symlink_root', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subdirectory', full_name='envoy.config.bootstrap.v4alpha.Runtime.subdirectory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_subdirectory', full_name='envoy.config.bootstrap.v4alpha.Runtime.override_subdirectory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='envoy.config.bootstrap.v4alpha.Runtime.base', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.config.bootstrap.v3.Runtime',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5023,
  serialized_end=5188,
)


_RUNTIMELAYER_DISKLAYER = _descriptor.Descriptor(
  name='DiskLayer',
  full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.DiskLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symlink_root', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.DiskLayer.symlink_root', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subdirectory', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.DiskLayer.subdirectory', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='append_service_cluster', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.DiskLayer.append_service_cluster', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.bootstrap.v3.RuntimeLayer.DiskLayer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5516,
  serialized_end=5660,
)

_RUNTIMELAYER_ADMINLAYER = _descriptor.Descriptor(
  name='AdminLayer',
  full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.AdminLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.bootstrap.v3.RuntimeLayer.AdminLayer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5662,
  serialized_end=5732,
)

_RUNTIMELAYER_RTDSLAYER = _descriptor.Descriptor(
  name='RtdsLayer',
  full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.RtdsLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.RtdsLayer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtds_config', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.RtdsLayer.rtds_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.bootstrap.v3.RuntimeLayer.RtdsLayer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5735,
  serialized_end=5879,
)

_RUNTIMELAYER = _descriptor.Descriptor(
  name='RuntimeLayer',
  full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_layer', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.static_layer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_layer', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.disk_layer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_layer', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.admin_layer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtds_layer', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.rtds_layer', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RUNTIMELAYER_DISKLAYER, _RUNTIMELAYER_ADMINLAYER, _RUNTIMELAYER_RTDSLAYER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.bootstrap.v3.RuntimeLayer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='layer_specifier', full_name='envoy.config.bootstrap.v4alpha.RuntimeLayer.layer_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=5191,
  serialized_end=5950,
)


_LAYEREDRUNTIME = _descriptor.Descriptor(
  name='LayeredRuntime',
  full_name='envoy.config.bootstrap.v4alpha.LayeredRuntime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='layers', full_name='envoy.config.bootstrap.v4alpha.LayeredRuntime.layers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.bootstrap.v3.LayeredRuntime',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5952,
  serialized_end=6079,
)

_BOOTSTRAP_STATICRESOURCES.fields_by_name['listeners'].message_type = envoy_dot_config_dot_listener_dot_v4alpha_dot_listener__pb2._LISTENER
_BOOTSTRAP_STATICRESOURCES.fields_by_name['clusters'].message_type = envoy_dot_config_dot_cluster_dot_v4alpha_dot_cluster__pb2._CLUSTER
_BOOTSTRAP_STATICRESOURCES.fields_by_name['secrets'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2._SECRET
_BOOTSTRAP_STATICRESOURCES.containing_type = _BOOTSTRAP
_BOOTSTRAP_DYNAMICRESOURCES.fields_by_name['lds_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_BOOTSTRAP_DYNAMICRESOURCES.fields_by_name['cds_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_BOOTSTRAP_DYNAMICRESOURCES.fields_by_name['ads_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._APICONFIGSOURCE
_BOOTSTRAP_DYNAMICRESOURCES.containing_type = _BOOTSTRAP
_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY.fields_by_name['value'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY.containing_type = _BOOTSTRAP
_BOOTSTRAP.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._NODE
_BOOTSTRAP.fields_by_name['static_resources'].message_type = _BOOTSTRAP_STATICRESOURCES
_BOOTSTRAP.fields_by_name['dynamic_resources'].message_type = _BOOTSTRAP_DYNAMICRESOURCES
_BOOTSTRAP.fields_by_name['cluster_manager'].message_type = _CLUSTERMANAGER
_BOOTSTRAP.fields_by_name['hds_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._APICONFIGSOURCE
_BOOTSTRAP.fields_by_name['stats_sinks'].message_type = envoy_dot_config_dot_metrics_dot_v4alpha_dot_stats__pb2._STATSSINK
_BOOTSTRAP.fields_by_name['stats_config'].message_type = envoy_dot_config_dot_metrics_dot_v4alpha_dot_stats__pb2._STATSCONFIG
_BOOTSTRAP.fields_by_name['stats_flush_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_BOOTSTRAP.fields_by_name['watchdogs'].message_type = _WATCHDOGS
_BOOTSTRAP.fields_by_name['layered_runtime'].message_type = _LAYEREDRUNTIME
_BOOTSTRAP.fields_by_name['admin'].message_type = _ADMIN
_BOOTSTRAP.fields_by_name['overload_manager'].message_type = envoy_dot_config_dot_overload_dot_v3_dot_overload__pb2._OVERLOADMANAGER
_BOOTSTRAP.fields_by_name['stats_server_version_override'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_BOOTSTRAP.fields_by_name['bootstrap_extensions'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_BOOTSTRAP.fields_by_name['fatal_actions'].message_type = _FATALACTION
_BOOTSTRAP.fields_by_name['config_sources'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_BOOTSTRAP.fields_by_name['default_config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_BOOTSTRAP.fields_by_name['certificate_provider_instances'].message_type = _BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY
_BOOTSTRAP.oneofs_by_name['stats_flush'].fields.append(
  _BOOTSTRAP.fields_by_name['stats_flush_interval'])
_BOOTSTRAP.fields_by_name['stats_flush_interval'].containing_oneof = _BOOTSTRAP.oneofs_by_name['stats_flush']
_BOOTSTRAP.oneofs_by_name['stats_flush'].fields.append(
  _BOOTSTRAP.fields_by_name['stats_flush_on_admin'])
_BOOTSTRAP.fields_by_name['stats_flush_on_admin'].containing_oneof = _BOOTSTRAP.oneofs_by_name['stats_flush']
_ADMIN.fields_by_name['address'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._ADDRESS
_ADMIN.fields_by_name['socket_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_socket__option__pb2._SOCKETOPTION
_CLUSTERMANAGER_OUTLIERDETECTION.fields_by_name['event_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_event__service__config__pb2._EVENTSERVICECONFIG
_CLUSTERMANAGER_OUTLIERDETECTION.containing_type = _CLUSTERMANAGER
_CLUSTERMANAGER.fields_by_name['outlier_detection'].message_type = _CLUSTERMANAGER_OUTLIERDETECTION
_CLUSTERMANAGER.fields_by_name['upstream_bind_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._BINDCONFIG
_CLUSTERMANAGER.fields_by_name['load_stats_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._APICONFIGSOURCE
_WATCHDOGS.fields_by_name['main_thread_watchdog'].message_type = _WATCHDOG
_WATCHDOGS.fields_by_name['worker_watchdog'].message_type = _WATCHDOG
_WATCHDOG_WATCHDOGACTION.fields_by_name['config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_WATCHDOG_WATCHDOGACTION.fields_by_name['event'].enum_type = _WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT
_WATCHDOG_WATCHDOGACTION.containing_type = _WATCHDOG
_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT.containing_type = _WATCHDOG_WATCHDOGACTION
_WATCHDOG.fields_by_name['actions'].message_type = _WATCHDOG_WATCHDOGACTION
_WATCHDOG.fields_by_name['miss_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['megamiss_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['kill_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['max_kill_timeout_jitter'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['multikill_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['multikill_threshold'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_FATALACTION.fields_by_name['config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_RUNTIME.fields_by_name['base'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RUNTIMELAYER_DISKLAYER.containing_type = _RUNTIMELAYER
_RUNTIMELAYER_ADMINLAYER.containing_type = _RUNTIMELAYER
_RUNTIMELAYER_RTDSLAYER.fields_by_name['rtds_config'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_RUNTIMELAYER_RTDSLAYER.containing_type = _RUNTIMELAYER
_RUNTIMELAYER.fields_by_name['static_layer'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RUNTIMELAYER.fields_by_name['disk_layer'].message_type = _RUNTIMELAYER_DISKLAYER
_RUNTIMELAYER.fields_by_name['admin_layer'].message_type = _RUNTIMELAYER_ADMINLAYER
_RUNTIMELAYER.fields_by_name['rtds_layer'].message_type = _RUNTIMELAYER_RTDSLAYER
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['static_layer'])
_RUNTIMELAYER.fields_by_name['static_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['disk_layer'])
_RUNTIMELAYER.fields_by_name['disk_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['admin_layer'])
_RUNTIMELAYER.fields_by_name['admin_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['rtds_layer'])
_RUNTIMELAYER.fields_by_name['rtds_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_LAYEREDRUNTIME.fields_by_name['layers'].message_type = _RUNTIMELAYER
DESCRIPTOR.message_types_by_name['Bootstrap'] = _BOOTSTRAP
DESCRIPTOR.message_types_by_name['Admin'] = _ADMIN
DESCRIPTOR.message_types_by_name['ClusterManager'] = _CLUSTERMANAGER
DESCRIPTOR.message_types_by_name['Watchdogs'] = _WATCHDOGS
DESCRIPTOR.message_types_by_name['Watchdog'] = _WATCHDOG
DESCRIPTOR.message_types_by_name['FatalAction'] = _FATALACTION
DESCRIPTOR.message_types_by_name['Runtime'] = _RUNTIME
DESCRIPTOR.message_types_by_name['RuntimeLayer'] = _RUNTIMELAYER
DESCRIPTOR.message_types_by_name['LayeredRuntime'] = _LAYEREDRUNTIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Bootstrap = _reflection.GeneratedProtocolMessageType('Bootstrap', (_message.Message,), {

  'StaticResources' : _reflection.GeneratedProtocolMessageType('StaticResources', (_message.Message,), {
    'DESCRIPTOR' : _BOOTSTRAP_STATICRESOURCES,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Bootstrap.StaticResources)
    })
  ,

  'DynamicResources' : _reflection.GeneratedProtocolMessageType('DynamicResources', (_message.Message,), {
    'DESCRIPTOR' : _BOOTSTRAP_DYNAMICRESOURCES,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Bootstrap.DynamicResources)
    })
  ,

  'CertificateProviderInstancesEntry' : _reflection.GeneratedProtocolMessageType('CertificateProviderInstancesEntry', (_message.Message,), {
    'DESCRIPTOR' : _BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Bootstrap.CertificateProviderInstancesEntry)
    })
  ,
  'DESCRIPTOR' : _BOOTSTRAP,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Bootstrap)
  })
_sym_db.RegisterMessage(Bootstrap)
_sym_db.RegisterMessage(Bootstrap.StaticResources)
_sym_db.RegisterMessage(Bootstrap.DynamicResources)
_sym_db.RegisterMessage(Bootstrap.CertificateProviderInstancesEntry)

Admin = _reflection.GeneratedProtocolMessageType('Admin', (_message.Message,), {
  'DESCRIPTOR' : _ADMIN,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Admin)
  })
_sym_db.RegisterMessage(Admin)

ClusterManager = _reflection.GeneratedProtocolMessageType('ClusterManager', (_message.Message,), {

  'OutlierDetection' : _reflection.GeneratedProtocolMessageType('OutlierDetection', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERMANAGER_OUTLIERDETECTION,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.ClusterManager.OutlierDetection)
    })
  ,
  'DESCRIPTOR' : _CLUSTERMANAGER,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.ClusterManager)
  })
_sym_db.RegisterMessage(ClusterManager)
_sym_db.RegisterMessage(ClusterManager.OutlierDetection)

Watchdogs = _reflection.GeneratedProtocolMessageType('Watchdogs', (_message.Message,), {
  'DESCRIPTOR' : _WATCHDOGS,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Watchdogs)
  })
_sym_db.RegisterMessage(Watchdogs)

Watchdog = _reflection.GeneratedProtocolMessageType('Watchdog', (_message.Message,), {

  'WatchdogAction' : _reflection.GeneratedProtocolMessageType('WatchdogAction', (_message.Message,), {
    'DESCRIPTOR' : _WATCHDOG_WATCHDOGACTION,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Watchdog.WatchdogAction)
    })
  ,
  'DESCRIPTOR' : _WATCHDOG,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Watchdog)
  })
_sym_db.RegisterMessage(Watchdog)
_sym_db.RegisterMessage(Watchdog.WatchdogAction)

FatalAction = _reflection.GeneratedProtocolMessageType('FatalAction', (_message.Message,), {
  'DESCRIPTOR' : _FATALACTION,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.FatalAction)
  })
_sym_db.RegisterMessage(FatalAction)

Runtime = _reflection.GeneratedProtocolMessageType('Runtime', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIME,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.Runtime)
  })
_sym_db.RegisterMessage(Runtime)

RuntimeLayer = _reflection.GeneratedProtocolMessageType('RuntimeLayer', (_message.Message,), {

  'DiskLayer' : _reflection.GeneratedProtocolMessageType('DiskLayer', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMELAYER_DISKLAYER,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.RuntimeLayer.DiskLayer)
    })
  ,

  'AdminLayer' : _reflection.GeneratedProtocolMessageType('AdminLayer', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMELAYER_ADMINLAYER,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.RuntimeLayer.AdminLayer)
    })
  ,

  'RtdsLayer' : _reflection.GeneratedProtocolMessageType('RtdsLayer', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMELAYER_RTDSLAYER,
    '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.RuntimeLayer.RtdsLayer)
    })
  ,
  'DESCRIPTOR' : _RUNTIMELAYER,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.RuntimeLayer)
  })
_sym_db.RegisterMessage(RuntimeLayer)
_sym_db.RegisterMessage(RuntimeLayer.DiskLayer)
_sym_db.RegisterMessage(RuntimeLayer.AdminLayer)
_sym_db.RegisterMessage(RuntimeLayer.RtdsLayer)

LayeredRuntime = _reflection.GeneratedProtocolMessageType('LayeredRuntime', (_message.Message,), {
  'DESCRIPTOR' : _LAYEREDRUNTIME,
  '__module__' : 'envoy.config.bootstrap.v4alpha.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v4alpha.LayeredRuntime)
  })
_sym_db.RegisterMessage(LayeredRuntime)


DESCRIPTOR._options = None
_BOOTSTRAP_STATICRESOURCES._options = None
_BOOTSTRAP_DYNAMICRESOURCES._options = None
_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY._options = None
_BOOTSTRAP.fields_by_name['stats_flush_interval']._options = None
_BOOTSTRAP.fields_by_name['stats_flush_on_admin']._options = None
_BOOTSTRAP.fields_by_name['overload_manager']._options = None
_BOOTSTRAP._options = None
_ADMIN._options = None
_CLUSTERMANAGER_OUTLIERDETECTION._options = None
_CLUSTERMANAGER._options = None
_WATCHDOGS._options = None
_WATCHDOG_WATCHDOGACTION.fields_by_name['event']._options = None
_WATCHDOG_WATCHDOGACTION._options = None
_WATCHDOG.fields_by_name['max_kill_timeout_jitter']._options = None
_WATCHDOG._options = None
_FATALACTION._options = None
_RUNTIME._options = None
_RUNTIMELAYER_DISKLAYER._options = None
_RUNTIMELAYER_ADMINLAYER._options = None
_RUNTIMELAYER_RTDSLAYER._options = None
_RUNTIMELAYER.oneofs_by_name['layer_specifier']._options = None
_RUNTIMELAYER.fields_by_name['name']._options = None
_RUNTIMELAYER._options = None
_LAYEREDRUNTIME._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/check_error.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/check_error.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\017CheckErrorProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.google/api/servicecontrol/v1/check_error.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\"\xbc\x06\n\nCheckError\x12;\n\x04\x63ode\x18\x01 \x01(\x0e\x32-.google.api.servicecontrol.v1.CheckError.Code\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\"\xe0\x05\n\x04\x43ode\x12\x1a\n\x16\x45RROR_CODE_UNSPECIFIED\x10\x00\x12\r\n\tNOT_FOUND\x10\x05\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x13\n\x0f\x41\x42USER_DETECTED\x10g\x12\x19\n\x15SERVICE_NOT_ACTIVATED\x10h\x12\x14\n\x10\x42ILLING_DISABLED\x10k\x12\x13\n\x0fPROJECT_DELETED\x10l\x12\x13\n\x0fPROJECT_INVALID\x10r\x12\x16\n\x12IP_ADDRESS_BLOCKED\x10m\x12\x13\n\x0fREFERER_BLOCKED\x10n\x12\x16\n\x12\x43LIENT_APP_BLOCKED\x10o\x12\x16\n\x12\x41PI_TARGET_BLOCKED\x10z\x12\x13\n\x0f\x41PI_KEY_INVALID\x10i\x12\x13\n\x0f\x41PI_KEY_EXPIRED\x10p\x12\x15\n\x11\x41PI_KEY_NOT_FOUND\x10q\x12\x1c\n\x18SECURITY_POLICY_VIOLATED\x10y\x12\x16\n\x12INVALID_CREDENTIAL\x10{\x12\x1c\n\x18LOCATION_POLICY_VIOLATED\x10|\x12\x14\n\x10\x43ONSUMER_INVALID\x10}\x12!\n\x1cNAMESPACE_LOOKUP_UNAVAILABLE\x10\xac\x02\x12\x1f\n\x1aSERVICE_STATUS_UNAVAILABLE\x10\xad\x02\x12\x1f\n\x1a\x42ILLING_STATUS_UNAVAILABLE\x10\xae\x02\x12\x1c\n\x17QUOTA_CHECK_UNAVAILABLE\x10\xaf\x02\x12/\n*CLOUD_RESOURCE_MANAGER_BACKEND_UNAVAILABLE\x10\xb1\x02\x12(\n#SECURITY_POLICY_BACKEND_UNAVAILABLE\x10\xb2\x02\x12(\n#LOCATION_POLICY_BACKEND_UNAVAILABLE\x10\xb3\x02\x42\x84\x01\n com.google.api.servicecontrol.v1B\x0f\x43heckErrorProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CHECKERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='google.api.servicecontrol.v1.CheckError.Code',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR_CODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=1, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=2, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_EXHAUSTED', index=3, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABUSER_DETECTED', index=4, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_NOT_ACTIVATED', index=5, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BILLING_DISABLED', index=6, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_DELETED', index=7, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_INVALID', index=8, number=114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IP_ADDRESS_BLOCKED', index=9, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERER_BLOCKED', index=10, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_APP_BLOCKED', index=11, number=111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_TARGET_BLOCKED', index=12, number=122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_KEY_INVALID', index=13, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_KEY_EXPIRED', index=14, number=112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_KEY_NOT_FOUND', index=15, number=113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECURITY_POLICY_VIOLATED', index=16, number=121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CREDENTIAL', index=17, number=123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_POLICY_VIOLATED', index=18, number=124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSUMER_INVALID', index=19, number=125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAMESPACE_LOOKUP_UNAVAILABLE', index=20, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_STATUS_UNAVAILABLE', index=21, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BILLING_STATUS_UNAVAILABLE', index=22, number=302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUOTA_CHECK_UNAVAILABLE', index=23, number=303,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUD_RESOURCE_MANAGER_BACKEND_UNAVAILABLE', index=24, number=305,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECURITY_POLICY_BACKEND_UNAVAILABLE', index=25, number=306,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_POLICY_BACKEND_UNAVAILABLE', index=26, number=307,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=203,
  serialized_end=939,
)
_sym_db.RegisterEnumDescriptor(_CHECKERROR_CODE)


_CHECKERROR = _descriptor.Descriptor(
  name='CheckError',
  full_name='google.api.servicecontrol.v1.CheckError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='google.api.servicecontrol.v1.CheckError.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detail', full_name='google.api.servicecontrol.v1.CheckError.detail', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHECKERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=939,
)

_CHECKERROR.fields_by_name['code'].enum_type = _CHECKERROR_CODE
_CHECKERROR_CODE.containing_type = _CHECKERROR
DESCRIPTOR.message_types_by_name['CheckError'] = _CHECKERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckError = _reflection.GeneratedProtocolMessageType('CheckError', (_message.Message,), {
  'DESCRIPTOR' : _CHECKERROR,
  '__module__' : 'google.api.servicecontrol.v1.check_error_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.CheckError)
  })
_sym_db.RegisterMessage(CheckError)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/listener/original_dst/v3/original_dst.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/listener/original_dst/v3/original_dst.proto',
  package='envoy.extensions.filters.listener.original_dst.v3',
  syntax='proto3',
  serialized_options=b'\n?io.envoyproxy.envoy.extensions.filters.listener.original_dst.v3B\020OriginalDstProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDenvoy/extensions/filters/listener/original_dst/v3/original_dst.proto\x12\x31\x65nvoy.extensions.filters.listener.original_dst.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"N\n\x0bOriginalDst:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.listener.original_dst.v2.OriginalDstB]\n?io.envoyproxy.envoy.extensions.filters.listener.original_dst.v3B\x10OriginalDstProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_ORIGINALDST = _descriptor.Descriptor(
  name='OriginalDst',
  full_name='envoy.extensions.filters.listener.original_dst.v3.OriginalDst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.config.filter.listener.original_dst.v2.OriginalDst',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=267,
)

DESCRIPTOR.message_types_by_name['OriginalDst'] = _ORIGINALDST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OriginalDst = _reflection.GeneratedProtocolMessageType('OriginalDst', (_message.Message,), {
  'DESCRIPTOR' : _ORIGINALDST,
  '__module__' : 'envoy.extensions.filters.listener.original_dst.v3.original_dst_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.original_dst.v3.OriginalDst)
  })
_sym_db.RegisterMessage(OriginalDst)


DESCRIPTOR._options = None
_ORIGINALDST._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/semantic_version.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/semantic_version.proto',
  package='envoy.type',
  syntax='proto3',
  serialized_options=b'\n\030io.envoyproxy.envoy.typeB\024SemanticVersionProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/type/semantic_version.proto\x12\nenvoy.type\x1a\x1dudpa/annotations/status.proto\"L\n\x0fSemanticVersion\x12\x14\n\x0cmajor_number\x18\x01 \x01(\r\x12\x14\n\x0cminor_number\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\rB:\n\x18io.envoyproxy.envoy.typeB\x14SemanticVersionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_SEMANTICVERSION = _descriptor.Descriptor(
  name='SemanticVersion',
  full_name='envoy.type.SemanticVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major_number', full_name='envoy.type.SemanticVersion.major_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_number', full_name='envoy.type.SemanticVersion.minor_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch', full_name='envoy.type.SemanticVersion.patch', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=156,
)

DESCRIPTOR.message_types_by_name['SemanticVersion'] = _SEMANTICVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SemanticVersion = _reflection.GeneratedProtocolMessageType('SemanticVersion', (_message.Message,), {
  'DESCRIPTOR' : _SEMANTICVERSION,
  '__module__' : 'envoy.type.semantic_version_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.SemanticVersion)
  })
_sym_db.RegisterMessage(SemanticVersion)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/client_ssl_auth/v3/client_ssl_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/client_ssl_auth/v3/client_ssl_auth.proto',
  package='envoy.extensions.filters.network.client_ssl_auth.v3',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.filters.network.client_ssl_auth.v3B\022ClientSslAuthProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nIenvoy/extensions/filters/network/client_ssl_auth/v3/client_ssl_auth.proto\x12\x33\x65nvoy.extensions.filters.network.client_ssl_auth.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9b\x02\n\rClientSSLAuth\x12\'\n\x10\x61uth_api_cluster\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x30\n\rrefresh_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12L\n\rip_white_list\x18\x04 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeB\x14\xf2\x98\xfe\x8f\x05\x0e\n\x0cip_allowlist:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.client_ssl_auth.v2.ClientSSLAuthBa\nAio.envoyproxy.envoy.extensions.filters.network.client_ssl_auth.v3B\x12\x43lientSslAuthProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CLIENTSSLAUTH = _descriptor.Descriptor(
  name='ClientSSLAuth',
  full_name='envoy.extensions.filters.network.client_ssl_auth.v3.ClientSSLAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_api_cluster', full_name='envoy.extensions.filters.network.client_ssl_auth.v3.ClientSSLAuth.auth_api_cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.client_ssl_auth.v3.ClientSSLAuth.stat_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_delay', full_name='envoy.extensions.filters.network.client_ssl_auth.v3.ClientSSLAuth.refresh_delay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_white_list', full_name='envoy.extensions.filters.network.client_ssl_auth.v3.ClientSSLAuth.ip_white_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\230\376\217\005\016\n\014ip_allowlist', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.filter.network.client_ssl_auth.v2.ClientSSLAuth',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=605,
)

_CLIENTSSLAUTH.fields_by_name['refresh_delay'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLIENTSSLAUTH.fields_by_name['ip_white_list'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._CIDRRANGE
DESCRIPTOR.message_types_by_name['ClientSSLAuth'] = _CLIENTSSLAUTH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientSSLAuth = _reflection.GeneratedProtocolMessageType('ClientSSLAuth', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSSLAUTH,
  '__module__' : 'envoy.extensions.filters.network.client_ssl_auth.v3.client_ssl_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.client_ssl_auth.v3.ClientSSLAuth)
  })
_sym_db.RegisterMessage(ClientSSLAuth)


DESCRIPTOR._options = None
_CLIENTSSLAUTH.fields_by_name['auth_api_cluster']._options = None
_CLIENTSSLAUTH.fields_by_name['stat_prefix']._options = None
_CLIENTSSLAUTH.fields_by_name['ip_white_list']._options = None
_CLIENTSSLAUTH._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto',
  package='envoy.extensions.filters.http.grpc_json_transcoder.v3',
  syntax='proto3',
  serialized_options=b'\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\017TranscoderProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nFenvoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto\x12\x35\x65nvoy.extensions.filters.http.grpc_json_transcoder.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc9\x07\n\x12GrpcJsonTranscoder\x12\x1a\n\x10proto_descriptor\x18\x01 \x01(\tH\x00\x12\x1e\n\x14proto_descriptor_bin\x18\x04 \x01(\x0cH\x00\x12\x10\n\x08services\x18\x02 \x03(\t\x12m\n\rprint_options\x18\x03 \x01(\x0b\x32V.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions\x12$\n\x1cmatch_incoming_request_route\x18\x05 \x01(\x08\x12 \n\x18ignored_query_parameters\x18\x06 \x03(\t\x12\x14\n\x0c\x61uto_mapping\x18\x07 \x01(\x08\x12\'\n\x1fignore_unknown_query_parameters\x18\x08 \x01(\x08\x12\x1b\n\x13\x63onvert_grpc_status\x18\t \x01(\x08\x12~\n\x11url_unescape_spec\x18\n \x01(\x0e\x32Y.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.UrlUnescapeSpecB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12&\n\x1estrict_http_request_validation\x18\x0b \x01(\x08\x1a\xe4\x01\n\x0cPrintOptions\x12\x16\n\x0e\x61\x64\x64_whitespace\x18\x01 \x01(\x08\x12%\n\x1d\x61lways_print_primitive_fields\x18\x02 \x01(\x08\x12\"\n\x1a\x61lways_print_enums_as_ints\x18\x03 \x01(\x08\x12\"\n\x1apreserve_proto_field_names\x18\x04 \x01(\x08:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions\"j\n\x0fUrlUnescapeSpec\x12\"\n\x1e\x41LL_CHARACTERS_EXCEPT_RESERVED\x10\x00\x12\x1f\n\x1b\x41LL_CHARACTERS_EXCEPT_SLASH\x10\x01\x12\x12\n\x0e\x41LL_CHARACTERS\x10\x02:@\x9a\xc5\x88\x1e;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoderB\x15\n\x0e\x64\x65scriptor_set\x12\x03\xf8\x42\x01\x42`\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\x0fTranscoderProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_GRPCJSONTRANSCODER_URLUNESCAPESPEC = _descriptor.EnumDescriptor(
  name='UrlUnescapeSpec',
  full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.UrlUnescapeSpec',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL_CHARACTERS_EXCEPT_RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_CHARACTERS_EXCEPT_SLASH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_CHARACTERS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=995,
  serialized_end=1101,
)
_sym_db.RegisterEnumDescriptor(_GRPCJSONTRANSCODER_URLUNESCAPESPEC)


_GRPCJSONTRANSCODER_PRINTOPTIONS = _descriptor.Descriptor(
  name='PrintOptions',
  full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='add_whitespace', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.add_whitespace', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_print_primitive_fields', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.always_print_primitive_fields', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_print_enums_as_ints', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.always_print_enums_as_ints', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preserve_proto_field_names', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.preserve_proto_field_names', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=993,
)

_GRPCJSONTRANSCODER = _descriptor.Descriptor(
  name='GrpcJsonTranscoder',
  full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proto_descriptor', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.proto_descriptor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_descriptor_bin', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.proto_descriptor_bin', index=1,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='services', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.services', index=2,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_options', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.print_options', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_incoming_request_route', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.match_incoming_request_route', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignored_query_parameters', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.ignored_query_parameters', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_mapping', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.auto_mapping', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_unknown_query_parameters', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.ignore_unknown_query_parameters', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convert_grpc_status', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.convert_grpc_status', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url_unescape_spec', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.url_unescape_spec', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strict_http_request_validation', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.strict_http_request_validation', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCJSONTRANSCODER_PRINTOPTIONS, ],
  enum_types=[
    _GRPCJSONTRANSCODER_URLUNESCAPESPEC,
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='descriptor_set', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.descriptor_set',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=221,
  serialized_end=1190,
)

_GRPCJSONTRANSCODER_PRINTOPTIONS.containing_type = _GRPCJSONTRANSCODER
_GRPCJSONTRANSCODER.fields_by_name['print_options'].message_type = _GRPCJSONTRANSCODER_PRINTOPTIONS
_GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec'].enum_type = _GRPCJSONTRANSCODER_URLUNESCAPESPEC
_GRPCJSONTRANSCODER_URLUNESCAPESPEC.containing_type = _GRPCJSONTRANSCODER
_GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set'].fields.append(
  _GRPCJSONTRANSCODER.fields_by_name['proto_descriptor'])
_GRPCJSONTRANSCODER.fields_by_name['proto_descriptor'].containing_oneof = _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']
_GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set'].fields.append(
  _GRPCJSONTRANSCODER.fields_by_name['proto_descriptor_bin'])
_GRPCJSONTRANSCODER.fields_by_name['proto_descriptor_bin'].containing_oneof = _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']
DESCRIPTOR.message_types_by_name['GrpcJsonTranscoder'] = _GRPCJSONTRANSCODER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GrpcJsonTranscoder = _reflection.GeneratedProtocolMessageType('GrpcJsonTranscoder', (_message.Message,), {

  'PrintOptions' : _reflection.GeneratedProtocolMessageType('PrintOptions', (_message.Message,), {
    'DESCRIPTOR' : _GRPCJSONTRANSCODER_PRINTOPTIONS,
    '__module__' : 'envoy.extensions.filters.http.grpc_json_transcoder.v3.transcoder_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions)
    })
  ,
  'DESCRIPTOR' : _GRPCJSONTRANSCODER,
  '__module__' : 'envoy.extensions.filters.http.grpc_json_transcoder.v3.transcoder_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder)
  })
_sym_db.RegisterMessage(GrpcJsonTranscoder)
_sym_db.RegisterMessage(GrpcJsonTranscoder.PrintOptions)


DESCRIPTOR._options = None
_GRPCJSONTRANSCODER_PRINTOPTIONS._options = None
_GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._options = None
_GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec']._options = None
_GRPCJSONTRANSCODER._options = None
# @@protoc_insertion_point(module_scope)
